@@ -3,7 +3,7 @@
 package ClickerWidget;
 use base 'Tickit::Widget';
 
-use strict;
+use v5.14;
 use warnings;
 
 use Tickit;
@@ -30,11 +30,11 @@ sub render_to_rb
 sub on_mouse
 {
    my $self = shift;
-   my ( $ev, $button, $line, $col ) = @_;
+   my ( $args ) = @_;
 
-   return unless $ev eq "press" and $button == 1;
+   return unless $args->type eq "press" and $args->button == 1;
 
-   push @points, [ $line, $col ];
+   push @points, [ $args->line, $args->col ];
    shift @points while @points > 10;
    $self->redraw;
 }
