@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.14;
 use warnings;
 
 use Tickit;
@@ -44,6 +44,10 @@ $vbox->add( Tickit::Widget::Static->new( text => "strikethrough", strike => 1 )
 
 $vbox->add( Tickit::Widget::Static->new( text => "reverse video", rv => 1 ) );
 
+$vbox->add( Tickit::Widget::Static->new( text => "blink", blink => 1 ) );
+
 $vbox->add( Tickit::Widget::Static->new( text => "alternate font", af => 1 ) );
 
-Tickit->new( root => $vbox )->run;
+my $t = Tickit->new( root => $vbox );
+$t->bind_key( q => sub { $t->stop } );
+$t->run;
