@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.14;
 use warnings;
 
 use Tickit;
@@ -29,7 +29,7 @@ foreach my $y ( 0 .. 5 ) {
    foreach my $x ( 0 .. 35 ) {
       my $col = $y * 36 + $x + 16;
       $hbox->add( Tickit::Widget::Static->new(
-         text => " ",
+         text => "  ",
          bg   => $col,
       ) );
    }
@@ -45,8 +45,4 @@ foreach my $g ( 0 .. 23 ) {
    ) );
 }
 
-my $tickit = Tickit->new();
-
-$tickit->set_root_widget( $vbox );
-
-$tickit->run;
+Tickit->new( root => $vbox )->run;
