@@ -1,17 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2021 -- leonerd@leonerd.org.uk
 
-package Tickit;
+package Tickit 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-BEGIN {
-   our $VERSION = '0.70';
-}
-
 use Carp;
 
 use IO::Handle;
@@ -69,13 +65,6 @@ via F<libtermkey> (all of these will require a supporting terminal as well).
 It also supports having multiple instances and non-blocking or asynchronous
 control.
 
-At the current version, this is a Perl distribution which contains and XS and
-C implementation of the lower levels (L<Tickit::Term> and L<Tickit::Pen>), and
-implements the higher levels (L<Tickit::Window> and L<Tickit::Widget>) in pure
-perl. The XS parts are supported by F<libtickit>, either from the installed
-library, or using a bundled copy compiled at build time. It is intended that
-eventually the Window layer will be rewritten in XS and C instead.
-
 =cut
 
 =head1 CONSTRUCTOR
@@ -188,6 +177,53 @@ sub _make_tickit
    return Tickit::_Tickit->new( @_ );
 }
 
+=head2 watch_io
+
+   $id = $tickit->watch_io( $fh, $cond, $code )
+
+I<Since version 0.71.>
+
+Runs the given CODE reference at some point in the future, when IO operations
+are possible on the given filehandle. C<$cond> should be a bitmask of at least
+one of the C<IO_IN>, C<IO_OUT> or C<IO_HUP> constants describing which kinds
+of IO operation the callback is interested in.
+
+Returns an opaque integer value that may be passed to L</watch_cancel>. This
+value is safe to ignore if not required.
+
+When invoked, the callback will receive an event parameter which will be an
+instances of a type with a field called C<cond>. This will contain the kinds
+of IO operation that are currently possible.
+
+   $code->( $info )
+
+   $current_cond = $info->cond;
+
+For example, to watch for both input and hangup conditions and respond to each
+individually:
+
+   $tickit->watch_io( $fh, Tickit::IO_IN|Tickit::IO_HUP,
+      sub {
+         my ( $info ) = @_;
+         if( $info->cond & Tickit::IO_IN ) {
+            ...
+         }
+         if( $info->cond & Tickit::IO_HUP ) {
+            ...
+         }
+      }
+   );
+
+=cut
+
+sub watch_io
+{
+   my $self = shift;
+   my ( $fh, $cond, $code ) = @_;
+
+   return $self->_tickit->watch_io( $fh->fileno, $cond, $code );
+}
+
 =head2 watch_later
 
    $id = $tickit->watch_later( $code )
@@ -287,6 +323,58 @@ sub timer
    croak "Mode should be 'at' or 'after'";
 }
 
+=head2 watch_signal
+
+   $id = $tickit->watch_signal( $signum, $code )
+
+I<Since version 0.72.>
+
+Runs the given CODE reference whenever the given POSIX signal is received.
+Signals are given by number, not name.
+
+Returns an opaque integer value that may be passed to L</watch_cancel>. This
+value is safe to ignore if not required.
+
+=cut
+
+sub watch_signal
+{
+   my $self = shift;
+   my ( $signum, $code ) = @_;
+
+   return $self->_tickit->watch_signal( $signum, $code );
+}
+
+=head2 watch_process
+
+   $id = $tickit->watch_process( $pid, $code )
+
+I<Since version 0.72.>
+
+Runs the given CODE reference when the given child process terminates.
+
+Returns an opaque integer value that may be passed to L</watch_cancel>. This
+value is safe to ignore if not required.
+
+When invoked, the callback will receive an event parameter which will be an
+instance of a type with a field called C<wstatus>. This will contain the exit
+status of the terminated child process.
+
+   $code->( $info )
+
+   $pid    = $info->pid;
+   $status = $info->wstatus;
+
+=cut
+
+sub watch_process
+{
+   my $self = shift;
+   my ( $pid, $code ) = @_;
+
+   return $self->_tickit->watch_process( $pid, $code );
+}
+
 =head2 watch_cancel
 
    $tickit->watch_cancel( $id )
@@ -476,7 +564,15 @@ sub run
       $widget->set_window( $self->rootwin );
    }
 
-   # TODO: $SIG{__DIE__} wrapping
+   my $term = $self->_tickit->term;
+   $SIG{__DIE__} = sub {
+      return if $^S;
+      my ( $err ) = @_;
+
+      # Teardown before application exit so the message appears properly
+      $term->teardown;
+      die $err;
+   };
 
    $self->_tickit->run;
 
