@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2009-2016 -- leonerd@leonerd.org.uk
 
-package Tickit::Event;
+package Tickit::Event 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.71';
-
 use Carp;
 
 =head1 NAME
