@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2011-2017 -- leonerd@leonerd.org.uk
 
-package Tickit::Pen;
+package Tickit::Pen 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.71';
-
 use Carp;
 
 our @ALL_ATTRS = qw( fg bg b u i rv strike af blink );
@@ -354,17 +352,15 @@ use overload
 use Scalar::Util qw( refaddr );
 use overload '==' => sub { refaddr($_[0]) == refaddr($_[1]) };
 
-package Tickit::Pen::Immutable;
+package Tickit::Pen::Immutable 0.72;
 use base qw( Tickit::Pen );
 use constant mutable => 0;
-our $VERSION = '0.71';
 
 sub as_immutable { return $_[0] }
 
-package Tickit::Pen::Mutable;
+package Tickit::Pen::Mutable 0.72;
 use base qw( Tickit::Pen );
 use constant mutable => 1;
-our $VERSION = '0.71';
 
 # Adds further methods in XS
 
