@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2012-2016 -- leonerd@leonerd.org.uk
 
-package Tickit::RectSet;
+package Tickit::RectSet 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.70';
-
 use List::Util qw( min max );
 
 # Load the XS code
