@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2013-2017 -- leonerd@leonerd.org.uk
 
-package Tickit::RenderBuffer;
+package Tickit::RenderBuffer 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.70';
-
 use Carp;
 use Scalar::Util qw( refaddr );
 
