@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2012-2016 -- leonerd@leonerd.org.uk
 
-package Tickit::StringPos;
+package Tickit::StringPos 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.70';
-
 # XS code comes from Tickit itself
 require Tickit;
 
