@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2009-2020 -- leonerd@leonerd.org.uk
 
-package Tickit::Term;
+package Tickit::Term 0.72;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.70';
-
 use Carp;
 
 # Load the XS code
@@ -113,17 +111,9 @@ sub new
    my $class = shift;
    my %params = @_;
 
-   my $self = $class->_new( $ENV{TERM} ) or croak "Cannot construct Tickit::Term - $!";
-
-   $self->set_input_handle ( $params{input_handle}  ) if $params{input_handle};
-   $self->set_output_handle( $params{output_handle} ) if $params{output_handle};
-
-   my $writer = $params{writer};
-   $self->set_output_func( sub { $writer->write( @_ ) } ) if $writer;
-
-   $self->set_utf8( $params{UTF8} ) if defined $params{UTF8};
-
-   return $self;
+   return $class->_new(
+      $ENV{TERM}, @params{qw( input_handle output_handle writer UTF8 )}
+   ) || croak "Cannot construct Tickit::Term - $!";
 }
 
 =head2 open_stdio
@@ -223,6 +213,15 @@ around a C<SIGSTOP>.
 
 =cut
 
+=head2 teardown
+
+   $term->teardown
+
+Shuts down operation of the terminal entirely, in preparation for terminating
+the process.
+
+=cut
+
 =head2 flush
 
    $term->flush
@@ -261,6 +260,10 @@ more of the following constants:
 
 Inserts this event handler first in the chain, before any existing ones.
 
+=item TICKIT_BIND_ONESHOT
+
+Remove the event handler after it has been invoked the first time.
+
 =back
 
 =head2 unbind_event_id
